@@ -48,7 +48,7 @@ from sure.registry import context as _registry
 if PY3:
     basestring = str
 
-version = '1.2.8'
+version = '1.2.9'
 
 
 not_here_error = \
@@ -803,11 +803,16 @@ class AssertionBuilder(object):
 
         return _that.raises(*args, **kw)
 
+    thrown = throw
+    raised = thrown
+
     @assertionmethod
     def return_value(self, value):
         return_value = self.obj(*self._callable_args, **self._callable_kw)
         return this(return_value).should.equal(value)
 
+    returned_the_value = return_value
+
     @assertionmethod
     def look_like(self, value):
         if self.negative:
